==> openjdk-10_10.0.2+13.orig.tar.xz: openjdk-10-10.0.2+13/src/hotspot/os/windows/semaphore_windows.hpp <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef OS_WINDOWS_VM_SEMAPHORE_WINDOWS_HPP
#define OS_WINDOWS_VM_SEMAPHORE_WINDOWS_HPP

#include "memory/allocation.hpp"

#include <windef.h>

class WindowsSemaphore : public CHeapObj<mtInternal> {
  HANDLE _semaphore;

  // Prevent copying and assignment.
  WindowsSemaphore(const WindowsSemaphore&);
  WindowsSemaphore& operator=(const WindowsSemaphore&);

 public:
  WindowsSemaphore(uint value = 0);
  ~WindowsSemaphore();

  void signal(uint count = 1);

  void wait();

  bool trywait();
};

typedef WindowsSemaphore SemaphoreImpl;

#endif // OS_WINDOWS_VM_SEMAPHORE_WINDOWS_HPP

==> openjdk-13_13.0.4+8.orig.tar.xz: openjdk-13-13.0.4+8/src/hotspot/os/windows/semaphore_windows.hpp <==
/*
 * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef OS_WINDOWS_SEMAPHORE_WINDOWS_HPP
#define OS_WINDOWS_SEMAPHORE_WINDOWS_HPP

#include "memory/allocation.hpp"

#include <windows.h>

class WindowsSemaphore : public CHeapObj<mtInternal> {
  HANDLE _semaphore;

  // Prevent copying and assignment.
  WindowsSemaphore(const WindowsSemaphore&);
  WindowsSemaphore& operator=(const WindowsSemaphore&);

 public:
  WindowsSemaphore(uint value = 0);
  ~WindowsSemaphore();

  void signal(uint count = 1);

  void wait();

  bool trywait();
};

typedef WindowsSemaphore SemaphoreImpl;

#endif // OS_WINDOWS_SEMAPHORE_WINDOWS_HPP
